<?php
// ----------------------------------------------------------------------
// File: $Id: pstimer.php,v 1.1 2003/11/10 13:10:44 hdonner Exp $
// ----------------------------------------------------------------------
// PHP-Nuke-VKP
// Copyright 2001-2004 by PHP-Nuke-VKP-Team
// http://developer.berlios.de/projects/phpnukevkp/
// ----------------------------------------------------------------------
// LICENSE
//
// Dieses Programm ist freie Software; Sie knnen sie beliebig verteilen
// und/oder nderungen vornehmen, solange Sie dieses unter den
// Lizenzbedingungen der Version 2 oder hher der GNU General Public
// License (GPL), verffentlicht von der Free Software Foundation tun.
//
// Dieses Programm wurde in der Hoffnung erstellt, dass es fr Sie
// ntzlich sein knnte. Es wird jedoch ohne jeden Anspruch auf
// Gewhrleistung verffentlicht. Sie knnen auch nicht davon ausgehen,
// dass das Programm Dinge verrichtet, wie es erwartet wird.
//
// Lesen Sie die Lizenzbedinguneg unter der URL
// http://www.gnu.org/copyleft/gpl.html fr weitere Details.
// ----------------------------------------------------------------------

/**
 * pstimer.php
 *
 * Diese Datei enthlt die Klasse psTimer.
 *
 * @author Hinrich Donner
 * @copyright Hinrich Donner 2003
 * @license LGPL
 * @version 0.1
 * @since 5.5.1
 * @package PHPSnippets
 * @subpackage Utilities
 * @category Datum und Zeit
 * @link http://sourceforge.net/projects/phpsnippets/
 */

/**
 * psTimer
 *
 * A simple timer class.
 */
class psTimer
{
    /**
     * _running
     *
     * Trigger the current state.
     *
     * @var bool
     * @access protected
     * @see phpsTimer::IsRunning()
     */
    var $_running = false;

    /**
     * start
     *
     * The start time or FALSE if not started.
     *
     * @var float
     * @see phpsTimer::Start(), phpsTimer::Stop()
     */
    var $start = false;

    /**
     * stop
     *
     * The stop time if started and stopped again or FALSE.
     *
     * @var float
     * @see phpsTimer::Start(), phpsTimer::Stop()
     */
    var $stop = false;

    /**
     * psTimer
     *
     * Constructor.
     */
    function psTimer()
    {
    }

    /**
     * GetMicroTime
     *
     * Returns the microtime as a string.  Taken from the PHP manual
     * example on microtime.  This method can be called without an
     * instance.
     *
     * @return float
     */
    function GetMicroTime()
    {
        list($usec, $sec) = explode(" ",microtime());
        return ((float)$usec + (float)$sec);
    }

    /**
     * Start
     *
     * Starts the timer.
     *
     * @return float The start time or FALSE if allready started
     * @see phpsTimer::Stop(), phpsTimer::Restart()
     */
    function Start()
    {
        if (!$this->IsRunning())
        {
            $this->start = $this->GetMicroTime();
            $this->stop = false;
            $this->_running = true;
        }
        return $this->start;
    }

    /**
     * Restart
     *
     * Restarts the timer.
     *
     * @return float The current time
     * @see phpsTimer::Start(), phpsTimer::Stop()
     */
    function Restart()
    {
        $this->start = $this->GetMicroTime();
        $this->_running = true;
        return $this->start;
    }

    /**
     * Stop
     *
     * Stop the timer.
     *
     * @return float The stop time or FALSE on error
     * @see phpsTimer::Start(), phpsTimer::Restart(), phpsTimer::Ellapsed()
     */
    function Stop()
    {
        if (!$this->IsRunning())
            return false;
        $this->stop = $this->GetMicroTime();
        $this->_running = false;
        return $this->stop;
    }

    /**
     * Ellapsed
     *
     * Returns the ellapsed time.
     *
     * @param int $round Maximum number of digits or -1 to get all
     * @return float The ellapsed time or FALSE on error
     * @see phpsTimer::Start(), phpsTimer::Stop()
     */
    function Ellapsed($round = -1)
    {
        if ($this->stop === false)
        {
            if ($this->start === false)
                return false;
            $result = $this->GetMicroTime() - $this->start;
        }
        else
            $result = $this->stop - $this->start;

        if ($round != -1)
            $result = round($result, (int) $round);
        return $result;
    }

    /**
     * IsRunning
     *
     * Returns the current state of the timer instance.
     *
     * @return bool TRUE or FALSE
     */
    function IsRunning()
    {
        return $this->_running;
    }

}

// $Log: pstimer.php,v $
// Revision 1.1  2003/11/10 13:10:44  hdonner
// - Zeitmessung fuer den Seitenaufbau als Makro in der Fusszeile
//
//
?>
