<?php
// ----------------------------------------------------------------------
// File: $Id: vkpconfig.php,v 1.3 2003/12/15 23:28:48 hdonner Exp $
// ----------------------------------------------------------------------
// PHP-Nuke-VKP
// Copyright 2001-2004 by PHP-Nuke-VKP-Team
// http://developer.berlios.de/projects/phpnukevkp/
// ----------------------------------------------------------------------
// LICENSE
//
// Dieses Programm ist freie Software; Sie knnen sie beliebig verteilen
// und/oder nderungen vornehmen, solange Sie dieses unter den
// Lizenzbedingungen der Version 2 oder hher der GNU General Public
// License (GPL), verffentlicht von der Free Software Foundation tun.
//
// Dieses Programm wurde in der Hoffnung erstellt, dass es fr Sie
// ntzlich sein knnte. Es wird jedoch ohne jeden Anspruch auf
// Gewhrleistung verffentlicht. Sie knnen auch nicht davon ausgehen,
// dass das Programm Dinge verrichtet, wie es erwartet wird.
//
// Lesen Sie die Lizenzbedinguneg unter der URL
// http://www.gnu.org/copyleft/gpl.html fr weitere Details.
// ----------------------------------------------------------------------

/**
 * vkpconfig.php
 *
 * Diese Datei enthlt die Klasse vkpConfig.
 *
 * @author Hinrich Donner
 * @copyright Hinrich Donner 2003
 * @license GPL
 * @version 0.1
 * @since 5.5.1
 * @package PHP-Nuke-VKP
 * @subpackage System
 * @category Konfiguration
 * @link http://developer.berlios.de/projects/phpnukevkp/
 */

/**
 * vkpConfig
 *
 * Diese Klasse kmmert sich um die Konfiguration.
 *
 * @author Hinrich Donner
 * @version 0.1
 * @since 5.5.1
 */
class vkpConfig
{
    /**
     * vkpConfig
     *
     * Der Konstruktor.
     *
     * @access protected
     * @see vkpConfig::GetInstance()
     * @author Hinrich Donner
     * @version 0.1
     * @since 5.5.1
     */
    function vkpConfig()
    {
        $this->_LoadValues();
    }

    /**
     * _LoadValues
     *
     * Mit dieser Methode werden alle Werte der Konfigurationsvariablen geladen
     *
     * @access protected
     * @author Hinrich Donner
     * @version 0.1
     * @since 5.5.1
     */
    function _LoadValues()
    {
        $PHP_SELF = $_SERVER['PHP_SELF'];

        include 'config.php';

        unset($PHP_SELF);

        foreach (get_defined_vars() as $name => $value)
        {
            if ($name == 'this')
                continue;
            $this->$name = $value;
        }
    }

    /**
     * GetInstance
     *
     * Diese Methode liefert eine einzige Instanz der Klasse (Singleton) zurck.
     * Es sollte ausschlielich diese Methode aufgerufen werden (anstatt von
     * new vkpConfig), um doppeltes Laden zu vermeiden.
     *
     * @return vkpConfig Die Instance
     * @author Hinrich Donner
     * @version 0.1
     * @since 5.5.1
     */
    function &GetInstance()
    {
        if (!array_key_exists('__vkp_config', $GLOBALS))
            $GLOBALS['__vkp_config'] =& new vkpConfig();
        return $GLOBALS['__vkp_config'];
    }

    /**
     * MakeCopyInGlobalScope
     *
     * Diese Methode erstellt eine Kopie der Konfigurationsvariablen
     * im globalen Namensraum.
     *
     * @author Hinrich Donner
     * @version 0.1
     * @since 5.5.1
     */
    function MakeCopyInGlobalScope()
    {
        foreach ($this as $name => $value)
            $GLOBALS[$name] = $value;
    }

    /**
     * VarExists
     *
     * Prft, ob eine bestimmte Konfigurationsvariable existiert.
     *
     * @param string $name Der Name
     * @return bool
     * @see vkpConfig::VarGet()
     * @author Hinrich Donner
     * @version 0.1
     * @since 5.5.1
     */
    function VarExists($name)
    {
        if (empty($name) || !isset($this->$name))
            return false;
        return true;
    }

    /**
     * VarGet
     *
     * Gibt den Wert einer Konfigurationsvariablen zurck.  Wenn die
     * Konfigurationsvariable nicht existiert, wird der Vorgabewert
     * zurckgegeben.
     *
     * @param string $name Der Name
     * @param mixed $default Ein Vorgabewert
     * @return mixed
     * @see vkpConfig::VarGetAllAsReference()
     * @author Hinrich Donner
     * @version 0.1
     * @since 5.5.1
     */
    function VarGet($name, $default = null)
    {
        if (!$this->VarExists($name))
            return $default;
        return $this->$name;
    }

    /**
     * VarGet
     *
     * Gibt die Werte aller Konfigurationsvariablen zurck.
     *
     * @return array
     * @see vkpConfig::VarGet()
     * @author Hinrich Donner
     * @version 0.1
     * @since 5.5.1
     */
    function VarGetAll()
    {
        $result = array();
        foreach ($this as $name => $value)
            $result[$name] = $value;
        return $result;
    }
}

/**
 * vkpConfigVarExists
 *
 * Prft, ob eine Variable existiert.
 *
 * @param string $name Der Name
 * @return bool
 * @see vkpConfig::VarExists()
 * @see vkpConfigVarGet()
 * @author Hinrich Donner
 * @version 0.1
 * @since 5.5.1
 */
function vkpConfigVarExists($name)
{
    static $config;

    if (!isset($config))
        $config =& vkpConfig::GetInstance();

    return $config->VarExists($name);
}

/**
 * vkpConfigVarGet
 *
 * Gibt den Wert einer Konfigurationsvariablen oder den Vorgabewert
 * zurck.
 *
 * @param string $name Der Name
 * @param mixed $default Der Vorgabewert
 * @return mixed Der Wert oder der Vorgabewert
 * @see vkpConfig::VarExists(), vkpConfig::VarGet()
 * @see vkpConfigVarExists()
 * @author Hinrich Donner
 * @version 0.1
 * @since 5.5.1
 */
function vkpConfigVarGet($name, $default = null)
{
    static $config;

    if (!isset($config))
        $config =& vkpConfig::GetInstance();

    return $config->VarGet($name, $default);
}

// $Log: vkpconfig.php,v $
// Revision 1.3  2003/12/15 23:28:48  hdonner
// - Rueckgabe aller Variablen als Array
//
// Revision 1.2  2003/12/05 21:49:37  hdonner
// - Umstellung bei dem Zugriff auf die Konfigurationsvariablen
//
// Revision 1.1  2003/12/01 17:11:07  hdonner
// - Admin!Einstellungen neu gegliedert
// - Einfache Html-Tools begonnen
//
//
?>
