<?php
// ----------------------------------------------------------------------
// File: $Id: vkpfile.php,v 1.2 2004/01/02 17:12:50 hdonner Exp $
// ----------------------------------------------------------------------
// PHP-Nuke-VKP
// Copyright 2001-2004 by PHP-Nuke-VKP-Team
// http://developer.berlios.de/projects/phpnukevkp/
// ----------------------------------------------------------------------
// LICENSE
//
// Dieses Programm ist freie Software; Sie knnen sie beliebig verteilen
// und/oder nderungen vornehmen, solange Sie dieses unter den
// Lizenzbedingungen der Version 2 oder hher der GNU General Public
// License (GPL), verffentlicht von der Free Software Foundation tun.
//
// Dieses Programm wurde in der Hoffnung erstellt, dass es fr Sie
// ntzlich sein knnte. Es wird jedoch ohne jeden Anspruch auf
// Gewhrleistung verffentlicht. Sie knnen auch nicht davon ausgehen,
// dass das Programm Dinge verrichtet, wie es erwartet wird.
//
// Lesen Sie die Lizenzbedinguneg unter der URL
// http://www.gnu.org/copyleft/gpl.html fr weitere Details.
// ----------------------------------------------------------------------

/**
 * vkpfile.php
 *
 * Diese Datei enthlt Klassen und Funktionen zur Handhabung
 * von Dateinamen, Dateien und Verzeichnissen.
 * 
 * @author Hinrich Donner
 * @version 5.5.1
 * @since 0.1
 * @package PHP-Nuke-VKP
 * @subpackage System
 * @category Dateisystem
 * @link http://developer.berlios.de/projects/phpnukevkp/
 */

/**
 * Bentigte Klassen 
 *
 * @ignore
 */
require_once VKP_INCLUDE_DIR . '/classes/vkparray.php';
require_once VKP_INCLUDE_DIR . '/classes/vkpstring.php';

/** 
 * vkpDirectory
 *
 * Diese Klasse behandelt ein Verzeichnis.
 * 
 * @author Hinrich Donner
 * @version 0.1
 * @since 5.5.1
 */
class vkpDirectory extends vkpArray
{
    /**
     * path
     * 
     * Der Pfad zum Verzeichnis. 
     *
     * @var vkpFilename
     */
    var $path = '.';
    
    /**
     * ignore
     * 
     * Eine Liste von Dateinamen, die beim Lesen ignoriert werden sollen.
     * 
     * @var array
     * @see vkpDirectory::$ignore_directories, vkpDirectory::$ignore_files
     */
    var $ignore = array('CVS');
    
    /**
     * ignore_directories
     * 
     * Wenn diese Eigenschaft gesetzt ist, werden Verzeichnisse in der Liste
     * nicht bercksichtigt.
     * 
     * @var bool
     * @see vkpDirectory::$ignore_files, vkpDirectory::$ignore
     */
    var $ignore_directories = false;
    
    /**
     * ignore_files
     * 
     * Wenn diese Eigenschaft gesetzt ist, werden Verzeichnisse in der Liste
     * nicht bercksichtigt.
     * 
     * @var bool
     * @see vkpDirectory::$ignore_directories, vkpDirectory::$ignore
     */
    var $ignore_files = false;
    
	/**
     * vkpDirectory
     *
     * Konstruktor
     *
     * @author Hinrich Donner
     * @version 0.1
     * @since 5.5.1
     */
	function vkpDirectory($path = '')
    {
        $this->vkpArray();
        $this->SetPath(&$path);
	}
    
    /**
     * SetPath
     *
     * Setzt den Pfadnamen.
     *
     * @param string $path
     * @author Hinrich Donner
     * @since 5.5.1
     * @version 0.1
     */
    function SetPath($path)
    {
    	if (!empty($path))
            $this->path = $path;
    }
    
    /**
     * Read
     *
     * Liest das angegebene Verzeichnis ein.
     *
     * @return bool TRUE oder FALSE im Fehlerfall
     * @author Hinrich Donner
     * @since 5.5.1
     * @version 0.1
     */
    function Read()
    {
        // Prfen, ob das Verzeichnis existiert
        //
        if (!file_exists($this->path)
                || @ !is_dir($this->path))
            return false;
        
        // Eventuell vorhandene Daten entfernen
        //
        $this->Clear();
    	$dir = dir($this->path);
        while (false !== ($name = $dir->read()))
        {
            if (in_array($name, $this->ignore))
                continue;
            
            if ($this->ignore_directories && @is_dir($this->path . '/' . $name))
                continue;
            
            if ($this->ignore_files && ! @is_dir($this->path . '/' . $name))
                continue;

            $this->Add($name);
        }
        $dir->close();
        return true;
    }

    /**
     * GetAll
     *
     * Liefert die Liste zurck.
     *
     * @param bool $with_path
     * @return array
     * @author Hinrich Donner
     * @since 5.5.1
     * @version 0.1
     */
    function GetAll($with_path = false)
    {
    	if (!$with_path)
            return parent::GetAll();
        $result = array();
        foreach ($this->items as $item)        
            $result[] = realpath($this->path . '/' . $item);
        return $result;
    }
        
} // Class

// $Log: vkpfile.php,v $
// Revision 1.2  2004/01/02 17:12:50  hdonner
// - OOP-API Themes
//
// Revision 1.1  2003/12/31 17:02:09  hdonner
// - Init
//
//
?>