<?php
// ----------------------------------------------------------------------
// File: $Id: vkpmember.php,v 1.2.2.2 2004/01/17 13:08:13 hdonner Exp $
// ----------------------------------------------------------------------
// PHP-Nuke-VKP
// Copyright 2001-2004 by PHP-Nuke-VKP-Team
// http://developer.berlios.de/projects/phpnukevkp/
// ----------------------------------------------------------------------
// LICENSE
//
// Dieses Programm ist freie Software; Sie knnen sie beliebig verteilen
// und/oder nderungen vornehmen, solange Sie dieses unter den
// Lizenzbedingungen der Version 2 oder hher der GNU General Public
// License (GPL), verffentlicht von der Free Software Foundation tun.
//
// Dieses Programm wurde in der Hoffnung erstellt, dass es fr Sie
// ntzlich sein knnte. Es wird jedoch ohne jeden Anspruch auf
// Gewhrleistung verffentlicht. Sie knnen auch nicht davon ausgehen,
// dass das Programm Dinge verrichtet, wie es erwartet wird.
//
// Lesen Sie die Lizenzbedinguneg unter der URL
// http://www.gnu.org/copyleft/gpl.html fr weitere Details.
// ----------------------------------------------------------------------

/**
 * vkpmember.php
 *
 * Diese Datei enthlt die Klasse vkpMember.
 *
 * @author Hinrich Donner
 * @version 0.1
 * @since 5.5.1
 * @package PHP-Nuke-VKP
 * @subpackage API (Klassen)
 * @category Benutzer
 * @link http://developer.berlios.de/projects/phpnukevkp/
 */

/**
 * Klassen einbinden
 *
 * @ignore
 */
require_once VKP_INCLUDE_DIR . '/classes/vkpdbtable.php';

/**
 * Klasse vkpMember
 *
 * Diese Klasse enthlt die notwendigen Methoden fr die Zugriffe auf
 * die Eigenschaften eines Benutzers.
 *
 * @author Hinrich Donner
 * @version 0.1
 * @since 5.5.1
 */
class vkpMember extends vkpDbTable
{
    /**
     * details
     *
     * Enthlt die Eigenschaften des aktuellen Administrators, wenn er
     * angemeldet ist, sonst eine leeres Array.
     *
     * @var array
     * @access public
     */
    var $details;

    /**
     * vkpMember
     *
     * Konstruktor
     *
     * @version 0.1
     * @since 5.5.1
     * @author Hinrich Donner
     */
    function vkpMember()
    {
        // Tabellenprefix holen
        //
        $config =& vkpConfig::GetInstance();

        // Konstruktor
        //
        $this->vkpDbTable($config->user_prefix . '_users');
    }

    /**
     * LoadById
     *
     * Ld einen Datensatz, wobei die Id als Suchkriterium verwendet wird.
     *
     * @param int $id Die id
     * @param bool $brief Wenn TRUE, dann werden nur wenige Felder geladen
     * @return array
     * @version 0.2
     * @since 5.5.1
     * @author Hinrich Donner
     */
    function LoadById($id, $brief = true)
    {
        $fields = (($brief) ? "`uid`,
                               `uname`,
                               `name`,
                               `email`,
                               `femail`
                               `user_viewemail`,
                               `url`,
                               `user_icq`,
                               `user_yim`,
                               `user_msnm`"
                            : '*');
        $sql    = "SELECT *
                   FROM `" . $this->tablename . "`
                   WHERE (`uid`='" . vkpVarPrepForStore($id) . "')";
        $dbr    = sql_query($sql);
        $result = sql_fetch_array($dbr);
        sql_free_result($dbr);
        return $result;
    }

    /**
     * LoadByUname
     *
     * Ld einen Datensatz, wobei der Benutzername als Suchkriterium verwendet wird.
     *
     * @param string $uname Der Benutzername (exakt)
     * @param bool $brief Wenn TRUE, dann werden nur wenige Felder geladen
     * @return array
     * @version 0.1
     * @since 5.5.1
     * @author Hinrich Donner
     */
    function LoadByUname($uname, $brief = true)
    {
        $fields = (($brief) ? "`uid`,
                               `uname`,
                               `name`,
                               `email`,
                               `femail`
                               `user_viewemail`,
                               `url`,
                               `user_icq`,
                               `user_yim`,
                               `user_msnm`"
                            : '*');
        $sql    = "SELECT *
                   FROM `" . $this->tablename . "`
                   WHERE (`uname`='" . vkpVarPrepForStore($uname) . "')";
        $dbr    = sql_query($sql);
        $result = sql_fetch_array($dbr);
        sql_free_result($dbr);
        return $result;
    }

    /**
     * Free
     *
     * Diese Methode gibt den belegten Speicher frei.
     *
     * @see vkpMember::Init(), vkpMember::Clear()
     * @version 0.1
     * @since 5.5.1
     * @author Hinrich Donner
     */
    function Free()
    {
        unset($this->details);
        $this->logged_in = false;
    }

    /**
     * Init
     *
     * Diese Methode initialisiert den Speicherbereich.
     *
     * @param array $source Der zu kopierende Datensatz
     * @version 0.1
     * @since 5.5.1
     * @author Hinrich Donner
     * @see vkpMember::Free(), vkpMember::Clear()
     */
    function Init($source = array())
    {
        $this->details = $source;
    }

    /**
     * Clear
     *
     * Diese Methode lscht die bisherigen Daten und initialisiert den
     * Datensatz.
     *
     * @version 0.1
     * @since 5.5.1
     * @author Hinrich Donner
     * @see vkpMember::Init(), vkpMember::Free()
     */
    function Clear()
    {
        $this->Free();
        $this->Init();
    }

    /**
     * GetAllAsReference
     *
     * Liefert eine Reference auf die Eigenschaft details
     *
     * @return array
     * @version 0.1
     * @since 5.5.1
     * @author Hinrich Donner
     * @see vkpUser::$details
     */
    function &GetAllAsReference()
    {
        return $this->details;
    }

    /**
     * GetId
     *
     * Liefert die Id des aktuellen Benutzers oder den Wert
     * von $anonymous der Konfiguration.
     *
     * @return string
     * @version 0.1
     * @since 5.5.1
     * @author Hinrich Donner
     */
    function GetId()
    {
        if ($this->LoggedIn())
            return $this->details['uid'];
        $config =& vkpConfig::GetInstance();
        return $config->anonymous;
    }

    /**
     * GetPasswd
     *
     * Liefert den MD5-Wert des Kennworts oder FALSE
     *
     * @return string
     * @version 0.1
     * @since 5.5.1
     * @author Hinrich Donner
     */
    function GetPasswd()
    {
        if ($this->LoggedIn())
            return $this->details['pass'];
        return false;
    }

    /**
     * GetUname
     *
     * Liefert den Benutzernamen
     *
     * @return string
     * @author Hinrich Donner
     * @version 0.1
     * @since 5.5.1
     */
    function GetUname()
    {
        if ($this->logged_in)
            return $this->details['uname'];
        return '';
    }

    /**
     * GetName
     *
     * Liefert den Namen
     *
     * @return string
     * @author Hinrich Donner
     * @version 0.1
     * @since 5.5.1
     */
    function GetName()
    {
        if ($this->logged_in)
            return $this->details['name'];
        return '';
    }

    /**
     * GetUrl
     *
     * Liefert die URL des Autors.
     *
     * @return string
     * @author Hinrich Donner
     * @version 0.1
     * @since 5.5.1
     */
    function GetUrl()
    {
        if ($this->logged_in)
        {
            $result = $this->details['url'];
            if (!preg_match("/^(http:|https:|gopher:|wais:)/", $result))
                $result = 'http://' . $result;
        }
        else
            $result = '';
        return $result;
    }

    /**
     * GetMail
     *
     * Liefert die Mailadresse in Abhngigkeit von den Einstellungen.
     *
     * @param bool $force Erzwingt die Rckgabe, auch wenn ausgeschaltet
     * @return string
     * @author Hinrich Donner
     * @version 0.1
     * @since 5.5.1
     */
    function GetMail($force = false)
    {
        if (!$this->logged_in || (!$this->details['user_viewemail'] && !$force))
            return '';

        $result = $this->GetFemail();
        if (empty($result))
            $result = $this->GetEmail();
        return $result;
    }

    /**
     * GetEmail
     *
     * Liefert die Mail-Adresse
     *
     * @return string
     * @author Hinrich Donner
     * @version 0.1
     * @since 5.5.1
     **/
    function GetEmail()
    {
        if ($this->logged_in)
            return $this->details['email'];
        return '';
    }

    /**
     * GetFemail
     *
     * Liefert die Fake-Mail-Adresse
     *
     * @return string
     * @author Hinrich Donner
     * @version 0.1
     * @since 5.5.1
     **/
    function GetFemail()
    {
        if ($this->logged_in)
            return $this->details['femail'];
        return '';
    }

    /**
     * GetUBlockOn
     *
     * Liefert den Status des Benutzerblocks zurck.
     *
     * @return bool
     * @author Hinrich Donner
     * @version 0.1
     * @since 5.5.1
     * @see vkpUser::GetUBlock()
     */
    function GetUBlockOn()
    {
        if ($this->logged_in)
            return $this->ublockon;
        return false;
    }

    /**
     * GetUBlock
     *
     * Gibt den Inhalt des Benutzerblocks zurck.
     *
     * @param bool $force Wenn TRUE, dann wird der Inhalt auch bei deaktiviertem Block zurckgegeben
     * @return string
     * @author Hinrich Donner
     * @version 0.1
     * @since 5.5.1
     * @see vkpUser::GetUBlockOn()
     */
    function GetUBlock($force = false)
    {
        if (($this->logged_in) && (($this->ublockon) || $force))
            return $this->ublock;
        return '';
    }

    /**
     * GetTheme
     *
     * Liefert das aktuelle Theme des Benutzers oder das Default-Theme.
     *
     * @return string
     * @author Hinrich Donner
     * @since 5.5.1
     * @version 0.1
     */
    function GetTheme()
    {
        return $this->GetVar('theme', $this->_config->Default_Theme);
    }

    /**
     * GetAvatar
     *
     * Liefert den Avatar des Benutzers.
     *
     * @return string
     * @author Hinrich Donner
     * @since 5.5.1
     * @version 0.1
     */
    function GetAvatar()
    {
        if ($this->logged_in)
            $result = 'images/forum/avatar/' . vkpVarPrepForOs($this->GetVar('user_avatar', 'blank.gif'));
        else
            $result = 'images/forum/avatar/blank.gif';
        return $result;
    }

    /**
     * GetRegisterDate
     *
     * Liefert einen Timestamp mit dem Datum der Registrierung.
     *
     * @return int Unix Timestamp
     * @author Hinrich Donner
     * @since 5.5.1
     * @version 0.1
     */
    function GetRegisterDate()
    {
        if (!$this->logged_in)
            return 0;

        $reg_date = $this->GetVar('user_regdate');
        $result = strtotime($reg_date);
        return $result;
    }

    /**
     * GetIcq
     *
     * Liefert die ICQ-Nummer des Benutzers, wenn dieser eine angegeben hat.
     *
     * @return string
     * @author Hinrich Donner
     * @since 5.5.1
     * @version 0.1
     * @see vkpMember::GetMsnm(), vkpMember::GetYim(), vkpMember::GetAim()
     */
    function GetIcq()
    {
        return $this->GetVar('user_icq', '');
    }

    /**
     * GetOccupation
     *
     * Liefert die Angabe zum Beruf des Benutzers zurck.
     *
     * @return string
     * @author Hinrich Donner
     * @since 5.5.1
     * @version 0.1
     */
    function GetOccupation()
    {
        return $this->GetVar('user_occ', '');
    }

    /**
     * GetFrom
     *
     * Liefert die Angabe zum Wohnort zurck.
     *
     * @return string
     * @author Hinrich Donner
     * @since 5.5.1
     * @version 0.1
     */
    function GetFrom()
    {
        return $this->GetVar('user_from', '');
    }

    /**
     * GetIterest
     *
     * Liefert die Angaben zu den Interessen zurck.
     *
     * @return string
     * @author Hinrich Donner
     * @since 5.5.1
     * @version 0.1
     */
    function GetIntrest()
    {
        return $this->GetVar('user_intrest', '');
    }

    /**
     * GetSignature
     *
     * Liefert die Signatur des Benutzers zurck.
     *
     * @param bool $force Wenn TRUE, dann wird die Signatur immer zurckgeliefert
     * @return string
     * @author Hinrich Donner
     * @since 5.5.1
     * @version 0.2
     */
    function GetSignature($force = false)
    {
        if ($this->GetVar('user_attachsig', false) || $force)
            return $this->GetVar('user_sig', '');
        return '';
    }

    /**
     * GetViewMail
     *
     * Liefert den Status, ob die Mail-Adresse sichtbar sein soll.
     *
     * @return bool
     * @author Hinrich Donner
     * @since 5.5.1
     * @version 0.1
     * @see vkpMember::GetMail(), vkpMember::GetEmail(), vkpMember::GetFemail()
     */
    function GetViewMail()
    {
        return $this->GetVar('user_viewemail', false);
    }

    /**
     * GetAim
     *
     * Liefert den Nick des AOL Instant Messaengers, wenn vorhanden
     *
     * @return string
     * @author Hinrich Donner
     * @since 5.5.1
     * @version 0.1
     * @see vkpMember::GetIcq(), vkpMember::GetYim(), vkpMember::GetMsnm()
     */
    function GetAim()
    {
        return $this->GetVar('user_aim', '');
    }

    /**
     * GetYim
     *
     * Liefert den Nick des Yahoo Instant Messaengers, wenn vorhanden
     *
     * @return string
     * @author Hinrich Donner
     * @since 5.5.1
     * @version 0.1
     * @see vkpMember::GetIcq(), vkpMember::GetMsnm(), vkpMember::GetAim()
     */
    function GetYim()
    {
        return $this->GetVar('user_yim', '');
    }

    /**
     * GetMsnm
     *
     * Liefert den Nick des MSN Instant Messaengers, wenn vorhanden
     *
     * @return string
     * @author Hinrich Donner
     * @since 5.5.1
     * @version 0.1
     * @see vkpMember::GetIcq(), vkpMember::GetYim(), vkpMember::GetAim()
     */
    function GetMsnm()
    {
        return $this->GetVar('user_msnm', '');
    }

    /**
     * GetStoriesOnHomepage
     *
     * Liefert die Anzahl der Artikel auf der Startseite
     *
     * @return int
     * @author Hinrich Donner
     * @since 5.5.1
     * @version 0.1
     */
    function GetStoriesOnHomepage()
    {
        $result = $this->GetVar('storynum', 0);
        if (empty($result))
        {
            $config =& vkpConfig::GetInstance();
            $result = $config->storyhome;
        }
        return $result;
    }

    /**
     * GetCommentMode
     *
     * Liefert den Anzeigemodus der Kommentare.
     *
     * @return string
     * @author Hinrich Donner
     * @since 5.5.1
     * @version 0.1
     * @see vkpMember::GetOrder(), vkpMember::GetBorder(), vkpMember::CommentLimit()
     */
    function GetCommentMode()
    {
        return $this->GetVar('umode', '');
    }

    /**
     * GetCommentBorder
     *
     * Liefert den Grenzwert fr die Anzeige der Kommentare
     *
     * @return int
     * @author Hinrich Donner
     * @since 5.5.1
     * @version 0.1
     * @see vkpMember::GetMode(), vkpMember::GetOrder(), vkpMember::CommentLimit()
     */
    function GetCommentBorder()
    {
        return $this->GetVar('thold', 0);
    }

    /**
     * GetCommentOrder
     *
     * Liefert die Reihenfolge fr die Anzeige der Kommentare
     *
     * @return int
     * @author Hinrich Donner
     * @since 5.5.1
     * @version 0.1
     * @see vkpMember::GetMode(), vkpMember::GetBorder(), vkpMember::CommentLimit()
     */
    function GetCommentOrder()
    {
        return $this->GetVar('uorder', 0);
    }

    /**
     * GetCommentLimit
     *
     * Liefert die maximale Anzahl von Bytes, die fr einen Kommentar
     * ausgegeben werden sollen.
     *
     * @return int
     * @author Hinrich Donner
     * @since 5.5.1
     * @version 0.1
     * @see vkpMember::GetMode(), vkpMember::GetBorder(), vkpMember::Order()
     */
    function GetCommentLimit()
    {
        $result = $this->GetVar('commentmax', 0);
        if ($result == 0)
        {
            $config =& vkpConfig::GetInstance();
            $result = $config->commentlimit;
        }
        return $result;
    }

    /**
     * GetNewsletter
     *
     * Ermittelt, ob der betreffende Benutzer den Newsletter bestellt hat.
     *
     * @return bool
     * @author Hinrich Donner
     * @since 5.5.1
     * @version 0.1
     */
    function GetNewsletter()
    {
        return $this->GetVar('newsletter');
    }

    /**
     * GetPosts
     *
     * Liefert die anzahl der Artikel zurck, die der Benutzer verfasst hat.
     *
     * @return int
     * @author Hinrich Donner
     * @since 5.5.1
     * @version 0.1
     */
    function GetPosts()
    {
        return $this->GetVar('user_posts');
    }

    /**
     * GetRank
     *
     * Liefert den aktuellen Rang des Benutzers zurck.
     *
     * @return int
     * @author Hinrich Donner
     * @since 5.5.1
     * @version 0.1
     */
    function GetRank()
    {
        return $this->GetVar('user_rank');
    }

    /**
     * GetLevel
     *
     * Liefert den aktuellel Level des Benutzers zurck.
     *
     * @return int
     * @author Hinrich Donner
     * @since 5.5.1
     * @version 0.1
     */
    function GetLevel()
    {
        return $this->GetVar('user_level');
    }
}

// $Log: vkpmember.php,v $
// Revision 1.2.2.2  2004/01/17 13:08:13  hdonner
// - API erweitert
//
// Revision 1.2  2004/01/02 17:12:50  hdonner
// - OOP-API Themes
//
// Revision 1.1  2003/12/31 17:02:34  hdonner
// - User: OOP-API
//
// Revision 1.1  2003/12/26 15:26:14  hdonner
// - Benutzerfunktionen ausgelagert
// - Klasse vkpUser begonnen
//
//
?>
