<?php
// ----------------------------------------------------------------------
// File: $Id: nexus.php,v 1.24.2.3 2004/01/17 22:36:05 hdonner Exp $
// ----------------------------------------------------------------------
// PHP-Nuke-VKP
// Copyright 2001-2004 by PHP-Nuke-VKP-Team
// http://developer.berlios.de/projects/phpnukevkp/
// ----------------------------------------------------------------------
// LICENSE
//
// Dieses Programm ist freie Software; Sie knnen sie beliebig verteilen
// und/oder nderungen vornehmen, solange Sie dieses unter den
// Lizenzbedingungen der Version 2 oder hher der GNU General Public
// License (GPL), verffentlicht von der Free Software Foundation tun.
//
// Dieses Programm wurde in der Hoffnung erstellt, dass es fr Sie
// ntzlich sein knnte. Es wird jedoch ohne jeden Anspruch auf
// Gewhrleistung verffentlicht. Sie knnen auch nicht davon ausgehen,
// dass das Programm Dinge verrichtet, wie es erwartet wird.
//
// Lesen Sie die Lizenzbedinguneg unter der URL
// http://www.gnu.org/copyleft/gpl.html fr weitere Details.
// ----------------------------------------------------------------------

/**
 * nexus.php
 *
 * Diese Datei enthlt die Funktionen, die man zur API zhlt. Dabei
 * handelt es sich um Funktionen, die im Standard PHP-Nuke nicht
 * vorhanden sind.
 *
 * @author Hinrich Donner
 * @version 0.1
 * @since 5.5.1
 * @package PHP-Nuke-VKP
 * @subpackage API
 * @category Verschiedenes
 * @link http://developer.berlios.de/projects/phpnukevkp/
 */

/**
 * Maximale Warstufe
 *
 * Der Nexus-Kern arbeitet mit der maximalen Warnstufe.
 *
 * @ignore
 */
$__vkp_error_reporting = error_reporting(E_ALL);

/**
 * VKP_VERSION
 *
 * Die Version des Sources. ndern Sie diese Konstante nicht, es sei denn,
 * Sie wissen genau, was Sie tun.
 */
define('VKP_VERSION', '5.5.1-BETA-0');

/**
 * PATH_TYPE_FILENAME
 *
 * Behandelt von Pfadangaben lediglich den Dateinamen.
 *
 * @see PATH_TYPE_RELATIVE, PATH_TYPE_FULL
 */
define('PATH_TYPE_FILENAME', 0);

/**
 * PATH_TYPE_RELATIVE
 *
 * Behandelt Dateinamen relativ zum Web-Root.
 *
 * @see PATH_TYPE_FILENAME, PATH_TYPE_FULL
 */
define('PATH_TYPE_RELATIVE', 1);

/**
 * PATH_TYPE_FULL
 *
 * Behandelt Dateinamen als vollstndige Pfadnamen.
 *
 * @see PATH_TYPE_RELATIVE, PATH_TYPE_FILENAME
 */
define('PATH_TYPE_FULL', 2);

/**
 * Klassen einbinden
 *
 * @ignore
 */
require_once VKP_INCLUDE_DIR . '/classes/pssession.php';
require_once VKP_INCLUDE_DIR . '/classes/vkpfile.php';
require_once VKP_INCLUDE_DIR . '/classes/vkpconfig.php';

/**
 * Andere Dateien einbinden
 *
 * @ignore
 */
require_once VKP_INCLUDE_DIR . '/vkpadmin.php';
require_once VKP_INCLUDE_DIR . '/vkpuser.php';
require_once VKP_INCLUDE_DIR . '/vkpmodules.php';
require_once VKP_INCLUDE_DIR . '/languages.php';
require_once VKP_INCLUDE_DIR . '/themes.php';

/**
 * Get Base URI
 *
 * Liefert die Basis URI des Servers.
 *
 * @return string
 * @see vkpGetBaseUrl()
 * @version 0.1
 * @since 5.5.1
 */
function vkpGetBaseUri()
{
    // Do a little caching
    //
    static $path;

    if (isset($path))
        return $path;

    // Start of with REQUEST_URI
    //
    if (isset($_SERVER['REQUEST_URI']))
        $path = $_SERVER['REQUEST_URI'];
    else
        $path = getenv('REQUEST_URI');

    if (empty($path) || (substr($path, -1, 1) == '/'))
    {
        // REQUEST_URI was empty or pointed to a path
        // Try looking at PATH_INFO
        //
        $path = getenv('PATH_INFO');
        if (empty($path))
        {
            // No luck there either
            // Try SCRIPT_NAME
            //
            if (isset($_SERVER['SCRIPT_NAME']))
                $path = $_SERVER['SCRIPT_NAME'];
            else
                $path = getenv('SCRIPT_NAME');
        }
    }

    $path = preg_replace('/[#\?].*/', '', $path);
    $path = dirname($path);

    if (preg_match('!^[/\\\]*$!', $path))
        $path = '';

    if (substr($path, strlen($path) - 1, 1) != '/')
        $path .= '/';
    return $path;
}

/**
 * Get Base URL
 *
 * Liefert die Basis-URL.
 *
 * @param bool $withpath Wenn TRUE wird der Pfad ebenfalls zurckgegeben
 * @return string Basis-URL
 * @see vkpGetBaseUri()
 * @version 0.1
 * @since 5.5.1
 */
function vkpGetBaseUrl($withpath = 1)
{
    static $result;

    // Da die Variable als Index verwendet wird, muss der Inhalt immer konsistent sein.
    //
    if ($withpath != 1)
        $withpath = 0;
    else
        $withpath = 1;

    // Altes Ergebnis nehmen, wenn mglich
    //
    if (isset($result) && array_key_exists($withpath, $result))
        return $result[$withpath];

    $result = array();

    if (empty($_SERVER['SERVER_NAME']))
        $server = getenv('HTTP_HOST');
    else
        $server = $_SERVER['SERVER_NAME'];

    if (vkpIsSecureProtocol())
        $proto = 'https://';
    else
        $proto = 'http://';

    $result[0] = $proto . $server;
    $result[1] = $proto . $server . vkpGetBaseUri();
    if (substr($result[1], strlen($result[1]) - 1, 1) != '/')
        $result[1] .= '/';

    return $result[$withpath];
}

/**
 * vkpIsSecureProtocol
 *
 * Testet, ob die Web-Site unter https luft.
 *
 * @return bool TRUE oder FALSE
 * @version 0.1
 * @since 5.5.1
 */
function vkpIsSecureProtocol()
{
    static $secure;

    if (isset($secure))
        return $secure;

    // IIS sets HTTPS=off
    //
    if (isset($_SERVER['HTTPS']) && $_SERVER['HTTPS'] != 'off')
        $secure = 1;
    else
        $secure = 0;

    return $secure;
}

/**
 * vkpCookieSet
 *
 * Setzt ein Cookie, wenn dies mglich ist.
 *
 * @param string $name Name des Cookies
 * @param mixed $value Der zu speichernde Wert
 * @param int $expire Die Lebenszeit des Cookies in Sekunden
 * @return bool TRUE wenn erfolgreich gesetzt, sonst FALSE
 * @see vkpCookieExists(), vkpCookieDelete()
 * @version 0.1
 * @since 5.5.1
 */
function vkpCookieSet($name, $value = '', $expire = 0)
{
    if (empty($name) || headers_sent())
        return false;

    // 0 indicates a lifetime during the session
    //
    if ($expire == 0)
        $_expire = 0;
    else
        $_expire = (time() + $expire);

    setcookie($name,
              $value,
              $_expire,
              vkpGetBaseUri(),
              $_SERVER['SERVER_NAME'],
              vkpIsSecureProtocol());
    $_COOKIE[$name] = $value;
    return true;
}

/**
 * vkpCookieExists
 *
 * Prft, ob ein bestimmtes Cookie existiert.
 *
 * @param string $name Der Name des Cookies
 * @return bool TRUE oder FALSE
 * @see vkpCookieSet(), vkpCookieDelete()
 * @version 0.1
 * @since 5.5.1
 */
function vkpCookieExists($name)
{
    return (!empty($name) && is_array($_COOKIE) && array_key_exists($name, $_COOKIE));
}

/**
 * vkpCookieGet
 *
 * Liefert den Inhalt eines Cookies.
 *
 * @param string $name Der Name des Cookies
 * @param mixed $default Ein Defaultwert
 * @return string Der Wert oder NULL, wenn das Cookie nicht existiert
 * @see vkpCookieExists()
 * @version 0.2
 * @since 0.1.1
 * @author Hinrich Donner
 */
function vkpCookieGet($name, $default = null)
{
    if (vkpCookieExists($name))
        return $_COOKIE[$name];
    return $default;
}

/**
 * vkpCookieDelete
 *
 * Lscht ein bestehendes Cookie
 *
 * @param string $name Der Name des Cookies
 * @return bool TRUE oder FALSE
 * @see vkpCookieExists(), vkpCookieSet()
 * @version 0.1
 * @since 5.5.1
 */
function vkpCookieDelete($name)
{
    if (!vkpCookieExists($name) || headers_sent())
        return false;

    setcookie($name,
              '',
              (time() - 3600),
              vkpGetBaseUri(),
              $_SERVER['SERVER_NAME'],
              vkpIsSecureProtocol());
    unset($_COOKIE[$name]);
    return true;
}

/**
 * vkpLocation
 *
 * Diese Funktion fhrt einen HTTP/1.0 korrekten Wechsel der Location aus.
 * Entgegen vielen anders lautenden Behauptungen und vor allem
 * Gepflogenheiten MUSS eine ABSOLUTE Adresse angegeben werden. Genau das
 * macht diese Funktion. Darber hinaus startet sie im Anschluss eine
 * HTML-Ausgabe, die versucht, die neue Adresse mittels Meta-Refresh
 * anzuspringen. Dadurch wird sichergestellt, dass auch diejenigen Browser,
 * die Location nicht untersttzen, am Ziel ankommen.
 *
 * @param string $url Die neue Adresse (relativ oder absolut)
 * @version 0.1
 * @since 5.5.1
 */
function vkpLocation($url = '')
{
    if (empty($url))
        $url = vkpGetBaseUrl();
    elseif ((substr($url, 0, 5) != 'http:') && (substr($url, 0, 6) != 'https:'))
    {
        if (substr($url, 0, 1) == '/')
            $url = vkpGetBaseUrl(false).$url;
        else
            $url = vkpGetBaseUrl().$url;
    }

    // Write down session information
    //
    session_write_close();

    $url = str_replace('&amp;', '&', $url);

    // Jump to the location, if possible
    //
    if (!headers_sent());
        Header("Location: {$url}");

    // Make an output for source
    //
    $target = str_replace('&', '&amp;', "{$url}");
    echo "<html>\n<head>\n<title>Redirected</title>\n"
        ."<meta http-equiv=\"refresh\" content=\"0; URL={$target}\">\n"
        ."</head>\n<body>\n<center><h1>Site Is Redirected</h1>\n"
        ."<p>If your browser does not jump to the target site,\n"
        ."please <a href=\"{$target}\">click here</a></p>\n"
        ."<p>The target address is:<br><br><b>{$target}</b></p>\n"
        ."</body>\n</html>\n";
    exit;
}

/**
 * vkpVarPrepForOs
 *
 * Bereitet einen oder mehrere Werte fr die Verwendung als Dateinamen vor.
 *
 * @param string $var,... Ein oder mehrere Werte
 * @return mixed Die aufbereiteten Werte als Array oder einen String
 * @version 0.1
 * @since 5.5.1
 */
function vkpVarPrepForOs()
{
    static $search  = array('!\.\./!si', // .. (directory traversal)
                            '!^.*://!si', // .*:// (start of URL)
                            '!/!si',     // Forward slash (directory traversal)
                            '!\\\\!si'); // Backslash (directory traversal)

    static $replace = array('',
                            '',
                            '_',
                            '_');

    $resarray = array();
    foreach (func_get_args() as $ourvar) {

        // Parse out bad things
        $ourvar = preg_replace($search, $replace, $ourvar);

        // Prepare var
        if (!get_magic_quotes_runtime())
            $ourvar = addslashes($ourvar);

        // Add to array
        array_push($resarray, $ourvar);
    }

    // Return vars
    if (func_num_args() == 1)
        return $resarray[0];
    else
        return $resarray;
}

/**
 * vkpStripSlashes
 *
 * Entfernt den Slash aus einer Variablen.
 *
 * @param mixed $value Eine Referenz auf die Variable
 * @version 0.1
 * @since 5.5.1
 */
function vkpStripSlashes(&$value)
{
    if(!is_array($value))
        $value = stripslashes($value);
    else
        array_walk($value,'vkpStripSlashes');
}

/**
 * vkpVarPrepForStore
 *
 * Bereitet eine Variable oder ein Array von Variablen fr die Verwendung
 * in einer SQL-Anweisung auf.
 *
 * @param mixed $var,... Wert oder Werte
 * @return mixed Das aufbereitete Ergebnis
 * @version 0.1
 * @since 5.5.1
 */
function vkpVarPrepForStore()
{
    $resarray = array();

    foreach (func_get_args() as $ourvar)
    {
        // Prepare var
        if (!get_magic_quotes_runtime())
            $ourvar = addslashes($ourvar);

        // Add to array
        array_push($resarray, $ourvar);
    }

    // Return vars
    if (func_num_args() == 1)
        return $resarray[0];
    else
        return $resarray;
}

/**
 * vkpVarAllFromInput
 *
 * Liefert alle bergebenen Variablen. Diese werden vorher NICHT geprft. Es
 * werden nur GET- und POST-Werte bercksichtigt.
 *
 * @return array
 * @see vkpVarFromInput()
 * @see vkpVarCleanFromInput()
 */
function vkpVarAllFromInput()
{
    static $request;

    if (isset($request))
        return $request;

    if (isset($_GET) && is_array($_GET))
        $get =& $_GET;
    else
        $get = array();
    if (isset($_POST) && is_array($_POST))
        $post =& $_POST;
    else
        $post = array();
    $request = array_merge($get, $post);

    return $request;
}

/**
 * vkpVarInputExists
 *
 * Testet, ob ein bestimmtes Argumet existiert.
 *
 * @param string $name Der Name
 * @return bool TRUE oder FALSE
 * @see vkpVarCleanFromInput()
 * @see vkpVarFromInput()
 * @see vkpVarAllFromInput()
 * @version 0.1
 * @since 5.5.1
 */
function vkpVarInputExists($name)
{
    $variables = vkpVarAllFromInput();
    return (bool) (!empty($name) && array_key_exists($name, $variables));
}

/**
 * vkpVarFromInput
 *
 * Liefert eine oder mehrere, ungeprfte Argumente.
 *
 * @param string $var,... Die Namen
 * @return mixed Die Werte
 * @see vkpVarCleanFromInput()
 * @see vkpVarAllFromInput()
 * @version 0.1
 * @since 5.5.1
 */
function vkpVarFromInput()
{
    $variables  = vkpVarAllFromInput();
    $resarray   = array();
    foreach (func_get_args() as $var)
    {
        if (empty($var))
            return;

        // Get var (order sessions override cookies override posts overrides gets
        //
        if (!array_key_exists($var, $variables))
        {
            array_push($resarray, NULL);
            continue;
        }
        unset($ourvar);
        $ourvar = $variables[$var];

        // Add to result array
        array_push($resarray, $ourvar);
    }

    // Return vars
    if (func_num_args() == 1)
        return $resarray[0];
    else
        return $resarray;
}

/**
 * vkpVarCleanFromInput
 *
 * Diese Funktion liefert ein oder mehrere Argumente. Gefhrliche Zeichen
 * werden dabei entfernt, wenn es sich bei dem aktuellen Benutzer nicht um
 * einen Admin handelt.
 *
 * @param string $var,... Die NAmen der Argumente
 * @return mixed Die bereinigten Werte
 * @see vkpVarFromInput()
 * @see vkpVarAllFromInput()
 * @version 0.1
 * @since 5.5.1
 */
function vkpVarCleanFromInput()
{
    static $search  = array('|</?\s*script.*?>|si',
                            '|</?\s*frame.*?>|si',
                            '|</?\s*object.*?>|si',
                            '|</?\s*img.*?>|si',
                            '|</?\s*meta.*?>|si',
                            '|</?\s*applet.*?>|si',
                            '|</?\s*link.*?>|si',
                            '|</?\s*iframe.*?>|si',
                            '|\([^>]*"?[^)]*\)|si',
                            '|style\s*=\s*"[^"]*"|si');
    static $replace = array('');

    $variables  = vkpVarAllFromInput();
    $resarray   = array();
    foreach (func_get_args() as $var)
    {
        if (empty($var))
            return;

        if (!array_key_exists($var, $variables))
        {
            array_push($resarray, NULL);
            continue;
        }
        unset($ourvar);
        $ourvar = $variables[$var];

        if (empty($ourvar))
        {
            array_push($resarray, $ourvar);
            continue;
        }

        // Clean var
        if (get_magic_quotes_gpc())
            vkpStripslashes($ourvar);

        // Bses entfernen
        //
        if (!vkpAdminLoggedIn())
            $ourvar = preg_replace($search, $replace, $ourvar);

        // Add to result array
        array_push($resarray, $ourvar);
    }

    // Return vars
    if (func_num_args() == 1)
        return $resarray[0];
    else
        return $resarray;
}

/**
 * vkpImageGetHtmlTag
 *
 * Diese Funktion erzeugt einen Image-Tag und gibt ihn zurck.  Die
 * Gre wird automatisch ermittelt, wenn es sich um ein lokales Bild
 * handelt.
 *
 * @param string $image Vollstndiger Pfad der Datei
 * @param $alt Alternativer Text
 * @param int $border Rahmenbreite in Pixel
 * @param int $hspace Horizontalabstand in Pixel
 * @param int $vspace Vertikalabstand in Pixel
 * @return string HTML-, aber nicht XHTML-kompatibler Image-Tag
 * @since 5.5.1
 * @version 0.1
 * @author Hinrich Donner
 */
function vkpImageGetHtmlTag($image, $alt = '', $align='', $border = 0, $hspace = 5, $vspace = 3)
{
    if (!preg_match("/^(http:|https:|ftp:)/i", $image)
        && file_exists($image))
    {
        $size           = getimagesize($image);
        $size_string    = strtolower($size[3]);
    }
    else
        $size_string    = '';

    if (!empty($align))
        $align = ' align="' . $align . '"';
    else
        $align = '';

    $result = "<img src=\"$image\" alt=\"$alt\"$align $size_string border=\"$border\" hspace=\"$hspace\" vspace=\"$vspace\">";
    return $result;
}

/**
 * vkpBbEncodePrivate
 *
 * Ersetzt BB-Code in privaten Nachrichten.  Der Source stammt ursprnglich aus
 * dem phpBB-Projekt.
 *
 * @param string $message Der Text
 * @return string
 */
function vkpBbEncodePrivate($message)
{
    global $prefix;
    // [CODE] and [/CODE] for posting code (HTML, PHP, C etc etc) in your posts.
    $matchCount = preg_match_all("#\[code\](.*?)\[/code\]#si", $message, $matches);

    for ($i = 0; $i < $matchCount; $i++)
    {
        $currMatchTextBefore = preg_quote($matches[1][$i]);
        $currMatchTextAfter = htmlspecialchars($matches[1][$i]);
        $message = preg_replace("#\[code\]$currMatchTextBefore\[/code\]#si",
                                "<!-- BBCode Start --><table border=\"0\" ALIGN=CENTER WIDTH=85%><TR><TD><span size=-1>Code:</span><HR></TD></TR><TR><TD><FONT SIZE=-1><PRE>$currMatchTextAfter</PRE></FONT></TD></TR><TR><TD><HR></TD></TR></TABLE><!-- BBCode End -->", $message);
    }

    // [QUOTE] and [/QUOTE] for posting replies with quote, or just for quoting stuff.
    $message = preg_replace("#\[quote\](.*?)\[/quote]#si", "<!-- BBCode Quote Start --><TABLE BORDER=0 ALIGN=CENTER WIDTH=85%><TR><TD><span size=-1>Quote:</span><HR></TD></TR><TR><TD><FONT SIZE=-1><BLOCKQUOTE>\\1</BLOCKQUOTE></FONT></TD></TR><TR><TD><HR></TD></TR></TABLE><!-- BBCode Quote End -->", $message);

    // [b] and [/b] for bolding text.
    $message = preg_replace("#\[b\](.*?)\[/b\]#si", "<!-- BBCode Start --><B>\\1</B><!-- BBCode End -->", $message);

    // [i] and [/i] for italicizing text.
    $message = preg_replace("#\[i\](.*?)\[/i\]#si", "<!-- BBCode Start --><I>\\1</I><!-- BBCode End -->", $message);

    // [url]www.phpbb.com[/url] code..
    $message = preg_replace("#\[url\](http://)?(.*?)\[/url\]#si", "<!-- BBCode Start --><A HREF=\"http://\\2\" TARGET=\"_blank\">\\2</A><!-- BBCode End -->", $message);

    // [url=www.phpbb.com]phpBB[/url] code..
    $message = preg_replace("#\[url=(http://)?(.*?)\](.*?)\[/url\]#si", "<!-- BBCode Start --><A HREF=\"http://\\2\" TARGET=\"_blank\">\\3</A><!-- BBCode End -->", $message);

    // [email]user@domain.tld[/email] code..
    $message = preg_replace("#\[email\](.*?)\[/email\]#si", "<!-- BBCode Start --><A HREF=\"mailto:\\1\">\\1</A><!-- BBCode End -->", $message);

    // [img]image_url_here[/img] code..
    $message = preg_replace("#\[img\](.*?)\[/img\]#si", "<!-- BBCode Start --><IMG SRC=\"\\1\"><!-- BBCode End -->", $message);

    // unordered list code..
    $matchCount = preg_match_all("#\[list\](.*?)\[/list\]#si", $message, $matches);

    for ($i = 0; $i < $matchCount; $i++)
    {
        $currMatchTextBefore = preg_quote($matches[1][$i]);
        $currMatchTextAfter = preg_replace("#\[\*\]#si", "<LI>", $matches[1][$i]);

        $message = preg_replace("#\[list\]$currMatchTextBefore\[/list\]#si", "<!-- BBCode ulist Start --><UL>$currMatchTextAfter</UL><!-- BBCode ulist End -->", $message);
    }

    // ordered list code..
    $matchCount = preg_match_all("#\[list=([a1])\](.*?)\[/list\]#si", $message, $matches);

    for ($i = 0; $i < $matchCount; $i++)
    {
        $currMatchTextBefore = preg_quote($matches[2][$i]);
        $currMatchTextAfter = preg_replace("#\[\*\]#si", "<LI>", $matches[2][$i]);

        $message = preg_replace("#\[list=([a1])\]$currMatchTextBefore\[/list\]#si", "<!-- BBCode olist Start --><OL TYPE=\\1>$currMatchTextAfter</OL><!-- BBCode olist End -->", $message);
    }

    return($message);
}

/**
 * vkpSmilieEncode
 *
 * Changes :) to an <IMG> tag based on the smiles table in the database.
 *
 * Smilies must be either:
 *         - at the start of the message.
 *         - at the start of a line.
 *         - preceded by a space or a period.
 * This keeps them from breaking HTML code and BBCode.
 * @todo Get rid of global variables.
 * @todo Funktion muss vollstndig berarbeitet werden
 * @param string $message Die Nachricht
 * @return string
 */
function vkpSmilieEncode($message)
{
    global $dbi, $prefix;

    // Pad it with a space so the regexp can match.
    $message = '' . $message;

    if ($getsmiles = sql_query("SELECT *, length(`code`) AS `length` FROM `" . $prefix . "_smiles` ORDER BY length DESC"))
    {
        while ($smiles = sql_fetch_array($getsmiles))
        {
            $smile_code = preg_quote($smiles['code']);
            $smile_code = str_replace('/', '//', $smile_code);
            $smile_code = str_replace('.', '\.', $smile_code);
            $message = preg_replace("/([\n\\ \\.])$smile_code/sie",
                                    '\1' . vkpImageGetHtmlTag('images/forum/smilies/' . $smiles['smile_url']),
                                    $message);
        }
    }
    return $message;
}

/**
 * vkpMakeClickable
 *
 * Rewritten by Nathan Codding - Feb 6, 2001.
 * - Goes through the given string, and replaces xxxx://yyyy with an HTML <a> tag linking
 *         to that URL
 * - Goes through the given string, and replaces www.xxxx.yyyy[zzzz] with an HTML <a> tag linking
 *         to http://www.xxxx.yyyy[/zzzz]
 * - Goes through the given string, and replaces xxxx@yyyy with an HTML mailto: tag linking
 *                to that email address
 * - Only matches these 2 patterns either after a space, or at the beginning of a line
 *
 * Notes: the email one might get annoying - it's easy to make it more restrictive, though.. maybe
 * have it require something like xxxx@yyyy.zzzz or such. We'll see.
 *
 * @param string $text Der Text
 * @return string
 */

function vkpMakeClickable($text)
{

        // pad it with a space so we can match things at the start of the 1st line.
        $ret = " " . $text;

        // matches an "xxxx://yyyy" URL at the start of a line, or after a space.
        // xxxx can only be alpha characters.
        // yyyy is anything up to the first space, newline, or comma.
        $ret = preg_replace("#([\n ])([a-z]+?)://([^, \n\r]+)#i", "\\1<!-- BBCode auto-link start --><a href=\"\\2://\\3\" target=\"_blank\">\\2://\\3</a><!-- BBCode auto-link end -->", $ret);

        // matches a "www.xxxx.yyyy[/zzzz]" kinda lazy URL thing
        // Must contain at least 2 dots. xxxx contains either alphanum, or "-"
        // yyyy contains either alphanum, "-", or "."
        // zzzz is optional.. will contain everything up to the first space, newline, or comma.
        // This is slightly restrictive - it's not going to match stuff like "forums.foo.com"
        // This is to keep it from getting annoying and matching stuff that's not meant to be a link.
        $ret = preg_replace("#([\n ])www\.([a-z0-9\-]+)\.([a-z0-9\-.\~]+)((?:/[^, \n\r]*)?)#i", "\\1<!-- BBCode auto-link start --><a href=\"http://www.\\2.\\3\\4\" target=\"_blank\">www.\\2.\\3\\4</a><!-- BBCode auto-link end -->", $ret);

        // matches an email@domain type address at the start of a line, or after a space.
        // Note: before the @ sign, the only valid characters are the alphanums and "-", "_", or ".".
        // After the @ sign, we accept anything up to the first space, linebreak, or comma.
        $ret = preg_replace("#([\n ])([a-z0-9\-_.]+?)@([^, \n\r]+)#i", "\\1<!-- BBcode auto-mailto start --><a href=\"mailto:\\2@\\3\">\\2@\\3</a><!-- BBCode auto-mailto end -->", $ret);

        // Remove our padding..
        $ret = substr($ret, 1);

        return($ret);
}

/**
 * vkpDie
 *
 * Eine etwas hbscher Art, das die() aufzurufen.
 *
 * @param string $reason Ein Text
 */
function vkpDie($reason = '')
{
    include 'header.php';
    title(_DIE);
    OpenTable();
    echo "<div class=\"content\">"
        . _DIE_HELP
        . "</div>\n"
        . "<ul compact><li>";

    if (empty($reason))
        echo _DIE_UNKNOWN;
    else
        echo $reason;
    echo "</li></ul>\n";
    CloseTable();
    die();
}

/**
 * vkpLanguageGetAll
 *
 * Liefert alle installierten Sprachnamen zurck.
 *
 * @return array
 * @version 0.1
 * @since 5.5.1
 * @author Hinrich Donner
 */
function vkpLanguageGetAll()
{
    static $result;

    if (isset($result))
        return $result;

    $result = array();

    $handle = opendir('language');
    while (false !== ($file = readdir($handle)))
    {
        if ((substr($file, 0, 5) == 'lang-') && ! @is_dir("language/$file"))
            $result[] = preg_replace("/^lang-([a-z0-9-_\.]+)\.php$/i", "\\1", $file);
    }
    closedir($handle);
    return $result;
}

/**
 * vkpSessionInit
 *
 * Initialisiert die Session.
 *
 * @version 0.1
 * @since 5.5.1
 * @uses psSession
 */
function vkpSessionInit()
{
    $session =& psSession::GetInstance();
}

/**
 * vkpSessionVarExists
 *
 * Prft, ob eine Variable in der Session gespeichert ist.
 *
 * @param string $name Der Name der Variablen
 * @return bool TRUE oder FALSE
 */
function vkpSessionVarExists($name)
{
    $session =& psSession::GetInstance();
    $result = $session->Exists($name);
    return $result;
}

/**
 * vkpSessionVarGet
 *
 * Liefert den Wert einer Session-Variablen oder den Default-Wert.
 *
 * @param string $name Der Name der Variablen
 * @param mixed $default Ein Default-Wert
 */
function vkpSessionVarGet($name, $default = null)
{
    $session =& psSession::GetInstance();
    if ($session->Exists($name))
        $result = $session->Get($name);
    else
        $result = $default;
    return $result;
}

/**
 * vkpSessionVarSet
 *
 * Setzt eine Session-Variable. Wenn diese bereits esistiert,
 * wird der Wert berschrieben.
 *
 * @param string $name Der Name der Variablen
 * @param mixed $value Der Wert
 * @return bool TRUE oder FALSE bei Fehlern
 */
function vkpSessionVarSet($name, $value)
{
    $session =& psSession::GetInstance();
    $result = $session->Set($name, $value);
    return $result;
}

/**
 * vkpSessionVarDelete
 *
 * Lscht eine bestehende Session-Variable.
 *
 * @param string $name Der Name der Variablen
 * @return bool TRUE oder FALSE bei Fehlern
 */
function vkpSessionVarDelete($name)
{
    $session =& psSession::GetInstance();
    $result = $session->Delete($name);
    return $result;
}

function vkpInit()
{
    vkpSessionInit();
    $config =& vkpConfig::GetInstance();
    setlocale(LC_ALL, $config->locale);

    // Datenbank-Anbindung
    require_once 'includes/sql_layer.php';
    $dbi = sql_connect($config->dbhost,
                       $config->dbuname,
                       $config->dbpass,
                       $config->dbname);

    // Instanzen erzeugen.
    //
    $user       =& vkpUser::GetInstance();
    $admin      =& vkpAdmin::GetInstance();
    $themes     =& vkpThemes::GetInstance();
    $languages  =& vkpLanguages::GetInstance();

    // Sprache initialisieren
    //
    _vkpLanguageInit();
}

/**
 * Initialisierungsteil des Nexus
 *
 * @ignore
 */
vkpInit();
//
// Warnstufe wiederherstellen
//
error_reporting($__vkp_error_reporting);

// $Log: nexus.php,v $
// Revision 1.24.2.3  2004/01/17 22:36:05  hdonner
// - Neue Konstanten
//
// Revision 1.24.2.2  2004/01/17 12:54:13  hdonner
// - Nutze API statt PHPNuke
//
// Revision 1.24.2.1  2004/01/10 12:04:07  hdonner
// - Version als Konstante
//
// Revision 1.24  2004/01/02 20:39:37  hdonner
// - Sprachsteuerung ueberarbeitet
//
// Revision 1.23  2004/01/02 17:10:40  hdonner
// - Initialisierungsvorgang
//
// Revision 1.22  2003/12/31 17:02:53  hdonner
// - User: OOP-API
//
// Revision 1.21  2003/12/26 15:26:14  hdonner
// - Benutzerfunktionen ausgelagert
// - Klasse vkpUser begonnen
//
// Revision 1.20  2003/12/17 17:39:36  hdonner
// - Modulhandler in OOP
//
// Revision 1.19  2003/12/15 23:27:58  hdonner
// - Auslagerung der Admin-Teile
//
// Revision 1.18  2003/12/11 12:53:21  hdonner
// - Locals am Start setzen
//
// Revision 1.17  2003/12/10 16:11:43  hdonner
// - Erneuerung des Cookies schafft Logout-Problem
//
// Revision 1.16  2003/12/08 18:28:13  hdonner
// - Fix: Pfad
//
// Revision 1.15  2003/12/08 17:55:53  hdonner
// - Fix: Cookie-Pfad
//
// Revision 1.14  2003/12/07 22:03:54  hdonner
// - themes.php enthaelt die API fuer Theme relevante Dinge
// - vkpThemeLogoHtmlTag() liefert einen HTML-Tag zurueck, um das Logo
//   anzeigen zu koennen. Ostern und Weihnachten werden dabei
//   beruecksichtigt.
//
// Revision 1.13  2003/12/05 21:49:37  hdonner
// - Umstellung bei dem Zugriff auf die Konfigurationsvariablen
//
// Revision 1.12  2003/12/01 17:11:07  hdonner
// - Admin!Einstellungen neu gegliedert
// - Einfache Html-Tools begonnen
//
// Revision 1.11  2003/11/30 14:31:50  hdonner
// - edituser angepasst
//
// Revision 1.10  2003/11/30 12:04:30  hdonner
// - Fix: Falsches Datenbankfeld
//
// Revision 1.9  2003/11/26 20:03:50  hdonner
// - Einige Userfunktionen
// - vkpImageGetHtmlTag: align eingefuegt
//
// Revision 1.8  2003/11/26 15:05:59  hdonner
// - Session-API
//
// Revision 1.7  2003/11/23 21:59:33  hdonner
// - Adminmenue der Startseite vollstaendig uberarbeitet.
//
// Revision 1.6  2003/11/23 16:28:53  hdonner
// - SQL-Logger eingebaut
//
// Revision 1.4  2003/11/23 11:54:42  hdonner
// - Modullader auf AdoDb umgestellt
//
// Revision 1.3  2003/11/22 10:25:05  hdonner
// - Weitere Funktionen
//
// Revision 1.2  2003/11/20 22:54:28  hdonner
// - Fix: Doppelte Abfrage
//
//
?>
