<?php
// ----------------------------------------------------------------------
// File: $Id: vkphtml.php,v 1.5 2003/12/26 15:25:38 hdonner Exp $
// ----------------------------------------------------------------------
// PHP-Nuke-VKP
// Copyright 2001-2004 by PHP-Nuke-VKP-Team
// http://developer.berlios.de/projects/phpnukevkp/
// ----------------------------------------------------------------------
// LICENSE
//
// Dieses Programm ist freie Software; Sie knnen sie beliebig verteilen
// und/oder nderungen vornehmen, solange Sie dieses unter den
// Lizenzbedingungen der Version 2 oder hher der GNU General Public
// License (GPL), verffentlicht von der Free Software Foundation tun.
//
// Dieses Programm wurde in der Hoffnung erstellt, dass es fr Sie
// ntzlich sein knnte. Es wird jedoch ohne jeden Anspruch auf
// Gewhrleistung verffentlicht. Sie knnen auch nicht davon ausgehen,
// dass das Programm Dinge verrichtet, wie es erwartet wird.
//
// Lesen Sie die Lizenzbedinguneg unter der URL
// http://www.gnu.org/copyleft/gpl.html fr weitere Details.
// ----------------------------------------------------------------------

/**
 * vkphtml.php
 *
 * Diese Datei enthlt einige Funktionen fr die leichtere Ausgabe von
 * einigen HTML Elementen.
 *
 * @author Hinrich Donner
 * @version 0.1
 * @since 5.5.1
 * @package PHP-Nuke-VKP
 * @subpackage System
 * @category Anzeige
 * @link http://developer.berlios.de/projects/phpnukevkp/
 */

/**
 * vkpHtmlBold
 * 
 * Fettschrift
 *                       
 * @param string $text Der Text
 * @param string $class Die HTML-Klasse
 * @param string $id Die ID
 * @param string $style Inline CSS
 * @return string Formartierter Text
 * @author Hinrich Donner           
 * @version 0.1
 * @since 5.5.1
 * @see vkpHtmlItalic()
 */
function vkpHtmlBold($text, $class = '', $id = '', $style = '')
{
    $result = '<b'
        . ((empty($class)) ? '' : ' class="' . $class . '"')
        . ((empty($id)) ? '' : ' id="' . $id . '"')
        . ((empty($style)) ? '' : ' style="' . $style . '"')
        . '>' . $text . '</b>';
    return $result;
}

/**
 * vkpHtmlItalic
 * 
 * Kursivschrift
 *                       
 * @param string $text Der Text
 * @param string $class Die HTML-Klasse
 * @param string $id Die ID
 * @param string $style Inline CSS
 * @return string Formartierter Text
 * @author Hinrich Donner           
 * @version 0.1
 * @since 5.5.1
 * @see vkpHtmlBold()
 */
function vkpHtmlItalic($text, $class = '', $id = '', $style = '')
{
    $result = '<i'
        . ((empty($class)) ? '' : ' class="' . $class . '"')
        . ((empty($id)) ? '' : ' id="' . $id . '"')
        . ((empty($style)) ? '' : ' style="' . $style . '"')
        . '>' . $text . '</i>';
    return $result;
}

function vkpHtmlSpan($text, $class = '', $id = '', $style = '')
{
    $result = '<span'
        . ((empty($class)) ? '' : ' class="' . $class . '"')
        . ((empty($id)) ? '' : ' id="' . $id . '"')
        . ((empty($style)) ? '' : ' style="' . $style . '"')
        . '>' . $text . '</span>';
    return $result;
}

function vkpHtmlLf($repeat = 1)
{
    return str_repeat('<br>', $repeat) . "\n";
}

function vkpHtmlSpace($repeat = 1)
{
    return str_repeat('&nbsp;', $repeat);
}

function vkpHtmlTextarea($name, $value, $rows = 5, $cols = 40, $class = '')
{
    $result = '<textarea name="' . $name . '"'
        . ((empty($class)) ? '' : ' class="' . $class . '"')
        . ' rows="' . $rows . '" cols="' . $cols . '">'
        . $value . "</textarea>\n";
    return $result;
}

/**
 * vkpHtmlSelectBox
 *
 * Erstellt eine Select-Box.
 *
 * @param string $name Der Name der Box
 * @param array $values Die Werte oder Wertepaare
 * @param string $selected Die vorgewhlte Option
 * @param bool $with_keys Wenn TRUE, dann wird der Index angezeigt und der Wert als 'value' genommen, sonst wird der Index ignoriert
 * @param string $class CSS-Klasse
 * @return string
 * @author Hinrich Donner
 * @version 0.1
 * @since 5.5.1
 * @see vkpHtmlYesNo()
 */
function vkpHtmlSelectBox($name, $values, $selected = false, $with_keys = false, $class = 'selectbox')
{
    if (empty($name) || empty($values) || !is_array($values))
        return '';

    $result = "<select name=\"$name\" class=\"$class\">\n";
    foreach ($values as $key => $value)
        $result .= "<option value=\"$value\"" . (($value == $selected) ? ' selected' : '') . ">"
            . (($with_keys) ? $key : $value) . "</option>\n";
    $result .= "</select>\n";
    return $result;
}

/**
 * vkpHtmlYesNo
 *
 * Erstellt eine Ja-Nein-Abfrage.
 *
 * @param string $name Der Name des Elementes
 * @param int $selected Die vorgewhlte Option (0 oder 1)
 * @param int $type Der Typ: 0 = Radio, 1 = Drop-Down, 2 = Checkbox
 * @param string $class CSS-Klasse (nur Drop-Down)
 * @return string
 * @author Hinrich Donner
 * @version 0.1
 * @since 5.5.1
 * @see vkpHtmlSelectBox(), vkpHtmlOnOff()
 */
function vkpHtmlYesNo($name, $selected = 0, $type = 0, $class = 'selectbox')
{
    $result = '';
    if (empty($name))
        return $result;

    switch ($type)
    {
        case 0:
            $result .= '<input type="radio" name="' . $name . '" value="1"' . (($selected == 1) ? ' checked' : '') . '>' . _YES
                . '&nbsp;<input type="radio" name="' . $name . '" value="0"' . (($selected == 0) ? ' checked' : '') . '>' . _NO
                . "\n";
            break;

        case 1:
            $result = "<select name=\"$name\" class=\"$class\">\n"
                . "<option value=\"1\"" . (($selected) ? ' selected' : '') . '>' . _YES . "</option>\n"
                . "<option value=\"0\"" . ((!$selected) ? ' selected' : '') . '>' . _NO . "</option>\n"
                . "</select>\n";
            break;

        case 2:
            $result = "<input type=\"checkbox\" name=\"$name\" value=\"1\""
                . (($selected) ? ' checked' : '') . ">\n";
            break;
    }
    return $result;
}

/**
 * vkpHtmlOnOff
 *
 * Erstellt eine An-Aus-Abfrage.
 *
 * @param string $name Der Name des Elementes
 * @param int $selected Die vorgewhlte Option (0 oder 1)
 * @param int $type Der Typ: 0 = Radio, 1 = Drop-Down, 2 = Checkbox
 * @param string $class CSS-Klasse (nur Drop-Down)
 * @return string
 * @author Hinrich Donner
 * @version 0.1
 * @since 5.5.1
 * @see vkpHtmlSelectBox(), vkpHtmlYesNo()
 */
function vkpHtmlOnOff($name, $selected = 0, $type = 0, $class = 'selectbox')
{
    $result = '';
    if (empty($name))
        return $result;

    switch ($type)
    {
        case 0:
            $result .= '<input type="radio" name="' . $name . '" value="1"' . (($selected == 1) ? ' checked' : '') . '>' . _BOOL_ON
                . '&nbsp;<input type="radio" name="' . $name . '" value="0"' . (($selected == 0) ? ' checked' : '') . '>' . _BOOL_OFF
                . "\n";
            break;

        case 1:
            $result = "<select name=\"$name\" class=\"$class\">\n"
                . "<option value=\"1\"" . (($selected) ? ' selected' : '') . '>' . _BOOL_ON . "</option>\n"
                . "<option value=\"0\"" . ((!$selected) ? ' selected' : '') . '>' . _BOOL_OFF . "</option>\n"
                . "</select>\n";
            break;

        case 2:
            $result = "<input type=\"checkbox\" name=\"$name\" value=\"1\""
                . (($selected) ? ' checked' : '') . ">\n";
            break;
    }
    return $result;
}

/**
 * vkpHtmlCalendarPopUp
 *
 * Zeigt ein Input-Feld (nur lesen) und einen Schalter an, der beim
 * Klicken einen JavaScript-Kalender anzeigt.
 *
 * @param string $label Ein voranzustellender Text
 * @param string $name Der Name des Input-Feldes
 * @return string
 * @author Hinrich Donner
 * @version 0.1
 * @since 5.5.1
 */
function vkpHtmlCalendarPopUp($label, $name)
{
    $result = vkpHtmlBold($label . ': ')
        . '<input type="text" name="' . $name .'" id="date" readonly>' . vkpHtmlSpace()
        . '<input type="button" id="trigger" value="' . _JSC_CALL_POPUP . '">'
        . "<script type=\"text/javascript\">\n"
        . "  Calendar.setup(\n"
        . "    {\n"
        . "      inputField  : \"date\",              // ID of the input field\n"
        . "      ifFormat    : \"%d.%m.%Y %H:%M\",    // the date format\n"
        . "      daFormat    : \"%d.%m.%Y %H:%M\",    // the date format\n"
        . "      button      : \"trigger\",           // ID of the button\n"
        . "      range       : [" . date('Y') . ", " . (date('Y') + 5) . "],       // Accectable years\n"
        . "      showsTime   : true,                // Time display\n"
        . "      weekNumbers : false                // No week numbers\n"
        . "    }\n"
        . "  );\n"
        . "// --></script>\n";
    return $result;
}

// $Log: vkphtml.php,v $
// Revision 1.5  2003/12/26 15:25:38  hdonner
// - Dokumentation ergaenzt
//
// Revision 1.4  2003/12/25 14:16:08  hdonner
// - JS-Kalender eingebunden
// - Kleine HTML-HElferlein
//
// Revision 1.3  2003/12/17 17:38:38  hdonner
// - Kursivschrift
//
// Revision 1.2  2003/12/13 13:14:52  hdonner
// - JavaScrip Calendar
//
// Revision 1.1  2003/12/01 17:11:07  hdonner
// - Admin!Einstellungen neu gegliedert
// - Einfache Html-Tools begonnen
//
//
?>
