<?php
// ----------------------------------------------------------------------
// File: $Id: index.php,v 1.2.2.1 2004/01/17 22:39:09 hdonner Exp $
// ----------------------------------------------------------------------
// PHP-Nuke-VKP
// Copyright 2001-2004 by PHP-Nuke-VKP-Team
// http://developer.berlios.de/projects/phpnukevkp/
// ----------------------------------------------------------------------
// LICENSE
//
// Dieses Programm ist freie Software; Sie knnen sie beliebig verteilen
// und/oder nderungen vornehmen, solange Sie dieses unter den
// Lizenzbedingungen der Version 2 oder hher der GNU General Public
// License (GPL), verffentlicht von der Free Software Foundation tun.
//
// Dieses Programm wurde in der Hoffnung erstellt, dass es fr Sie
// ntzlich sein knnte. Es wird jedoch ohne jeden Anspruch auf
// Gewhrleistung verffentlicht. Sie knnen auch nicht davon ausgehen,
// dass das Programm Dinge verrichtet, wie es erwartet wird.
//
// Lesen Sie die Lizenzbedinguneg unter der URL
// http://www.gnu.org/copyleft/gpl.html fr weitere Details.
// ----------------------------------------------------------------------

/**
 * index.php.php
 *
 * Die Hauptdatei fr das Modul Topics.
 *
 * @author Hinrich Donner
 * @author F. Bruzi
 * @version 0.2
 * @since 5.5.1
 * @package PHP-Nuke-VKP
 * @subpackage Module
 * @category Topics
 * @link http://developer.berlios.de/projects/phpnukevkp/
 */

/**
 * Klassen einbinden
 *
 * @ignore
 */
require_once VKP_INCLUDE_DIR . '/classes/vkparray.php';
require_once VKP_INCLUDE_DIR . '/classes/vkprecordset.php';

/**
 * Topics
 *
 * Diese Klasse verwaltet eine Liste von Themen.
 *
 * @author Hinrich Donner
 * @version 0.1
 * @since 5.5.1
 * @see Topic
 */
class Topics extends vkpAssocArray
{
    /**
     * Topics
     *
     * Der Konstruktor.
     *
     * @author Hinrich Donner
     * @version 0.1
     * @since 5.5.1
     */
    function Topics()
    {
        $this->vkpAssocArray();
    }

    /**
     * Load
     *
     * Ld die gesamte Liste.
     *
     * @return bool FALSE bei Datenbankfehlern, sonst TRUE
     * @author Hinrich Donner
     * @version 0.1
     * @since 5.5.1
     */
    function Load()
    {
        $this->Clear();
        $config =& vkpConfig::GetInstance();
        $sql    = "SELECT `topicid`        AS `id`,
                          `topicname`      AS `name`,
                          `topicimage`     AS `image`,
                          `topictext`      AS `description`,
                          `counter`        AS `hits`
                   FROM `" . $config->prefix . "_topics`
                   ORDER BY `topicname` ASC";
        if (false === ($dbr = sql_query($sql)))
            return false;

        while ($a_topic = sql_fetch_array($dbr))
            $this->items[$a_topic['name']] =& new Topic($a_topic);

        return true;
    }
}

/**
 * TopicsModule
 *
 * Diese Klasse stellt den Modulhandler dar.
 *
 * @author Hinrich Donner
 * @version 0.1
 * @since 5.5.1
 */
class TopicsModule extends vkpModuleFrame
{
    /**
     * TopicsModule
     *
     * Der Konstruktor
     *
     * @param string $module_name Der physikalische Name des Moduls.
     * @author Hinrich Donner
     * @version 0.1
     * @since 5.5.1
     */
    function TopicsModule($module_name)
    {
        $this->vkpModuleFrame($module_name);
        $modules =& vkpModules::GetInstance();
        $modules->$module_name->LoadLibrary();
    }

    /**
     * Header
     *
     * Startet die Ausgabe.
     *
     * @author Hinrich Donner
     * @version 0.1
     * @since 5.5.1
     */
    function Header()
    {
        parent::Header(_ACTIVETOPICS);
        $this->SearchBlock();
    }

    /**
     * SearchBlock
     *
     * Gibt den Suchblock aus, sofern dieses in der Konfiguration angegben wurde.
     *
     * @author Hinrich Donner
     * @version 0.1
     * @since 5.5.1
     */
    function SearchBlock()
    {
        // Search Block abgeschaltet?
        //
        if (!$this->config->topics_display_search_block)
            return;

        // Suchformular
        //
        if (vkpModuleIsActive('Search'))
        {
            OpenTable();
            echo '<div align="center">'
                . "<span class=\"content\">" . _TOPICS_SEARCH . "</span><br><br>\n"
                . "<form action=\"modules.php?name=Search\" method=\"post\">\n"
                . "<input type=\"name\" name=\"query\" size=\"30\">&nbsp;&nbsp;"
                . "<input type=\"submit\" value=\""._SEARCH."\">"
                . "</form></div>\n";
            CloseTable();
            echo "<br>\n";
        }
    }

    /**
     * Display
     *
     * Lsst das Modul laufen.  Da das Topics-Modul recht langweilig ist, ist
     * hier nicht viel los.
     *
     * @author Hinrich Donner
     * @version 0.1
     * @since 5.5.1
     */
    function Display()
    {
        $topics =& new Topics();
        $topics->Load();

        $_current_cell  = 1;
        $_news_module   = vkpModuleIsActive('News');
        $_items_per_row = $this->config->topics_items_per_row + 1;
        $_cell_width    = sprintf('%0.0f', (1 / $this->config->topics_items_per_row) * 100);

        $this->Header();
        OpenTable();
        echo '<p class="content">' . _TOPICS_DESCRIPTION . "</p>\n"
            . "<table border=\"0\" width=\"100%\" align=\"center\" cellpadding=\"2\">\n";
        foreach ($topics->GetAllAsReference() as $topic)
        {
            if ($_current_cell == 1)
                echo "<tr>\n";
            $link   = (($_news_module)
                    ? '<a href="modules.php?name=News&amp;new_topic=' . $topic->id . '">%s</a><br>'
                    : '%s<br>');
            $image  = vkpImageGetHtmlTag($topic->GetImage(),
                                         $topic->description);
            echo '<td align="center" width="' . $_cell_width . '%"><span class="content">' . sprintf($link, $image)
                 . '<span title="'
                 . sprintf('%0d ' . (($topic->hits == 1) ? '' . _TOPICS_HIT : '' . _TOPICS_HITS), $topic->hits)
                 . '">' . $topic->description . "</span></span></td>\n";
            ++$_current_cell;
            if ($_current_cell == $_items_per_row)
            {
                $_current_cell == 1;
                echo "</tr>\n";
            }
        }
        if ($_current_cell != 1)
        {
            for ($i = $_current_cell; $i < $_items_per_row; $i++)
                echo "<td>&nbsp;</td>\n";
            echo "</tr>\n";
        }
        echo "</table>\n<br>\n";
        CloseTable();
        echo "<br>\n";
        $this->SearchBlock();
        $this->Footer();
    }
}

/**
 * Modul anschieben
 *
 * @ignore
 */
$topics =& new TopicsModule(basename(dirname(__FILE__)));
$topics->Display();

// $Log: index.php,v $
// Revision 1.2.2.1  2004/01/17 22:39:09  hdonner
// - Topics auf OOP umgestellt
//
// Revision 1.2  2003/12/10 21:35:42  hdonner
// - Anzahl der Bildelemente je Zeile konfigurierbar
// - Darstellung des Suchblocks abschaltbar
//
//
?>
